@@ -19,9 +19,22 @@
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # 
 
+import os
+import subprocess
 import re
 import collections
 
+import pyalpm
+pyalpm.initialize()
+
+# read pacman.conf
+pyalpm.options.dbpath = "/var/lib/pacman"
+for i in open('/etc/pacman.conf'):
+	m = re.match('\s*DBPath\s*=\s*([\S^#]+)', i)
+	if m != None:
+		pyalpm.options.dbpath = m.group(1)
+		break
+
 DEPENDS_RE = re.compile("([^<>=:]+)([<>]?=.*)?(: .*)?")
 
 def strip_depend_info(value):
@@ -46,6 +59,7 @@ class PacmanPackage(collections.MutableMapping):
 		'pkgdesc': 'desc',
 		'size': 'isize',
 		'optdepend': 'optdepends',
+		'license': 'licenses'
 		}
 
 	@classmethod
@@ -168,4 +182,72 @@ class PacmanPackage(collections.MutableMapping):
 			return ("PacmanPackage(%s,[%s])" %
 					(repr(self._data), children))
 
+def load_from_pkgbuild(path):
+	# Load all the data like we normally would
+	workingdir = os.path.dirname(path)
+	if workingdir == '':
+		workingdir = None
+	filename = os.path.basename(path)
+	process = subprocess.Popen(['parsepkgbuild', filename],
+			stdout=subprocess.PIPE, stderr=subprocess.PIPE, cwd=workingdir)
+	out, err = process.communicate()
+	out = out.decode('utf-8', 'ignore')
+	err = err.decode('utf-8', 'ignore')
+	# this means parsepkgbuild returned an error, so we are not valid
+	if process.returncode > 0:
+		if out:
+			print("Error:", out)
+		if err:
+			print("Error:", err, file=sys.stdout)
+		return None
+	ret = PacmanPackage(db = out)
+
+	# Add a nice little .pkgbuild surprise
+	pkgbuild = open(path, errors="ignore")
+	ret.pkgbuild = pkgbuild.read().replace("\\\n", " ").splitlines()
+	pkgbuild.close()
+
+	return ret
+
+def load_from_alpm(pmpkg):
+	variables = ['name', 'version', 'conflicts', 'url',
+			'depends', 'desc', 'files', 'groups',
+			'has_scriptlet', 'size', 'licenses',
+			'optdepends', 'packager', 'provides', 'replaces']
+	values = dict((v, getattr(pmpkg, v)) for v in variables)
+
+	# arch is a list for PKGBUILDs, we do the same for tarball packages
+	values['arch'] = [pmpkg.arch]
+	# also drop md5sums for backed up files
+	values['backup'] = [name for (name, md5) in pmpkg.backup]
+
+	return PacmanPackage(data = values)
+
+def load_from_tarball(path):
+	try:
+		p = pyalpm.load_pkg(path)
+	except pyalpm.error:
+		return None
+
+	return load_from_alpm(p)
+
+def load_from_db(pkgname, dbname = None):
+	if dbname is None:
+		# default is loading local database
+		db = pyalpm.get_localdb()
+	else:
+		db = pyalpm.register_syncdb(dbname)
+	p = db.get_pkg(pkgname)
+
+	if p is None:
+		p = lookup_provider(pkgname)
+	if p is not None:
+		p = load_from_alpm(p)
+	return p
+
+def lookup_provider(pkgname):
+	for pkg in pyalpm.get_localdb().pkgcache:
+		if pkgname in pkg.provides:
+			return pkg
+
 # vim: set ts=4 sw=4 noet:
