@@ -24,7 +24,7 @@ import unittest
 import tempfile
 import shutil
 
-import pacman
+import Namcap.package
 import Namcap.ruleclass
 
 class PkgbuildTest(unittest.TestCase):
@@ -52,7 +52,7 @@ class PkgbuildTest(unittest.TestCase):
 	def run_on_pkg(self, p):
 		with open(self.tmpname, 'w', encoding = 'utf-8') as f:
 			f.write(p)
-		pkginfo = pacman.load(self.tmpname)
+		pkginfo = Namcap.package.load_from_pkgbuild(self.tmpname)
 		r = self.rule()
 		if isinstance(r, Namcap.ruleclass.PkgInfoRule):
 			if pkginfo.is_split:
@@ -82,6 +82,7 @@ _basic = """
 pkgname=mypackage
 pkgver=1.0
 pkgrel=1
+epoch=1
 pkgdesc="A package"
 arch=('i686' 'x86_64')
 url="http://www.example.com/"
@@ -111,6 +112,7 @@ pkgbase=mysplitpackage
 pkgname=('mypackage1' 'mypackage2' 'mypackage3')
 pkgver=1.0
 pkgrel=1
+epoch=2
 arch=('i686' 'x86_64')
 url="http://www.example.com/"
 license=('GPL')
